function CV=crossval_haz_cond(h,Y,X,d,type,typew,kernel,parallel)
% CROSSVALIDATION
% inputs: h       ...smoothing parameters, matrix with two columns (first column for time, second for covariate)
%         Y       ...observed times, vector
%         d       ...censoring indicator, vector, 0..censor, 1..event
%         kernel  ...one of: 'epan','gauss','quart','rect','trian'
%                    'epan'... default
%         type    ...type of estimate,
%                    possible: 'ex' ... exterior
%                              'in' ... interior, default
%         typew   ...type of weights
%         parallel...way of calculating
%                    FALSE ... common way
%                    TRUE  ... use more cores of computer
% output: vector of values of crossvalidation for smoothing parameters in h
%

if isvector(h)
    h=row(h);
end
a=0;
n=length(Y);

nh=size(h,1);

CV=zeros(1,nh);

hx=h(:,2);
ht=h(:,1);

if parallel
    parfor ii=1:nh
        b=max(Y)+ht(ii);
        I1pom=Trapezoid('I1',a,b,500,X,Y,X,d,[ht(ii) hx(ii)],kernel,type,typew);
        S=0;
        for j=1:n
            Yj=Y;
            Xj=X;
            dj=d;
            Yj(j)=[];
            Xj(j)=[];
            dj(j)=[];
            
            S=S+1/n*I1pom(j)-2/n*hazard_cond(Y(j),X(j),Yj,Xj,dj,[ht(ii) hx(ii)],kernel,type,typew)^2/surv_cond(Y(j),X(j),Y,X,d,[ht(ii) hx(ii)],kernel,typew)*d(j)*exp(-Trapezoid('hazard_cond',a,Y(j),500,X(j),Yj,Xj,dj,[ht(ii) hx(ii)],kernel,type,typew));
            
        end
        
        CV(ii)=S;
        
    end
    
else
    for ii=1:nh
       b=max(Y)+ht(ii);
        I1pom=Trapezoid('I1',a,b,500,X,Y,X,d,[ht(ii) hx(ii)],kernel,type,typew);
        S=0;
        for j=1:n
            Yj=Y;
            Xj=X;
            dj=d;
            Yj(j)=[];
            Xj(j)=[];
            dj(j)=[];
            
            S=S+1/n*I1pom(j)-2/n*hazard_cond(Y(j),X(j),Yj,Xj,dj,[ht(ii) hx(ii)],kernel,type,typew)^2/surv_cond(Y(j),X(j),Y,X,d,[ht(ii) hx(ii)],kernel,typew)*d(j)*exp(-Trapezoid('hazard_cond',a,Y(j),500,X(j),Yj,Xj,dj,[ht(ii) hx(ii)],kernel,type,typew));
            
        end
        
        CV(ii)=S;
        
    end
    
end


end
