function ML=maxlike_haz_cond(h,Y,X,d,type,typew,kernel,parallel)
% Log of likelihood function
% inputs: h       ...smoothing parameters, matrix with two columns (first column for time, second for covariate)
%         Y       ...observed times, vector
%         d       ...censoring indicator, vector, 0..censor, 1..event
%         kernel  ...one of: 'epan','gauss','quart','rect','trian'
%                    'epan'... default
%         type    ...type of estimate,
%                    possible: 'ex' ... exterior
%                              'in' ... interior, default
%         parallel...way of calculating
%                    FALSE ... common way
%                    TRUE  ... use more cores of computer
% output: vector of values of loglikelihood for smoothing parameters in h
%

if isvector(h)
    h=row(h);
end
a=0;
n=length(Y);

nh=size(h,1);

ML=zeros(1,nh);

hx=h(:,2);
ht=h(:,1);

if parallel
    parfor ii=1:nh
        S=0;
        for j=1:n
            Yj=Y;
            Xj=X;
            dj=d;
            Yj(j)=[];
            Xj(j)=[];
            dj(j)=[];
            
            S=S+log(hazard_cond(Y(j),X(j),Yj,Xj,dj,[ht(ii) hx(ii)],kernel,type,typew)^d(j)*exp(-Trapezoid('hazard_cond',a,Y(j),500,X(j),Yj,Xj,dj,[ht(ii) hx(ii)],kernel,type,typew)));
            
        end
        
        ML(ii)=S;
        
    end
    
    
else
    for ii=1:nh
        S=0;
        for j=1:n
            Yj=Y;
            Xj=X;
            dj=d;
            Yj(j)=[];
            Xj(j)=[];
            dj(j)=[];
            
            S=S+log(hazard_cond(Y(j),X(j),Yj,Xj,dj,[ht(ii) hx(ii)],kernel,type,typew)^d(j)*exp(-Trapezoid('hazard_cond',a,Y(j),500,X(j),Yj,Xj,dj,[ht(ii) hx(ii)],kernel,type,typew)));
            
        end
        
        ML(ii)=S;
        
    end
    
end


end
