function haz=hazard(t,Y,d,h,kernel,type)
% KERNEL ESTIMATION OF HAZARD FUNCTION
% inputs: t     ...time points in which we want calculate hazard, vector
%         Y     ...observed times, vector
%         d     ...censoring indicator, vector, 0..censor, 1..event
%         h     ...smoothing parameter, number
%         kernel...one of: 'epan','gauss','quart','rect'
%                  'epan'... default
%         type  ...type of estimate,
%                  possible: 'ex' ... exterior
%                            'in' ... interior, default
% output: vector of hazard values in times t

% if nargin == 4
%     kernel = 'epan';
%     type = 'interior';
% elseif nargin == 5
%     type = 'interior';
% elseif nargin<4
%     error('Malo vstupnich parametru')
% end

I=find(isfinite(Y)&isfinite(d));
Y=Y(I);
d=d(I);

K=K_def(kernel);
W=W_def(K);

switch type
    case 'interior'
        [YY,in]=sort(Y);
        YY=row(YY);
        dd=row(d(in));
        tt=row(t);
        
        
        n=length(Y);
        m=length(tt);
        
        %matice Y-tt
        Ymat=YY'*ones(1,m)-ones(n,1)*tt;
        
        dmat=(dd./(n-linspace(1,n,n)+1))'*ones(1,m);
        s=(K_val(K,(Ymat)/h)/h).*dmat;
        
        % keyboard
        haz=sum(s);
        
    case 'exterior'
        tt=row(t);
        
        Y=row(Y);
        d=row(d);
        n=length(Y);
        m=length(tt);
        
        %matice Y-tt
        Ymat=Y'*ones(1,m)-ones(n,1)*tt;
        %vypocet jmenovatele pro odstraneni nulovych hodnot
        t=(W_val(W,Ymat/h));
        % keyboard
        Jm=sum(t);
        Jm(Jm<=0.005)=0.005;
        
        dmat=d'*ones(1,m);
        s=(K_val(K,(-Ymat)/h)/h).*dmat;
        
        
        Ci=sum(s);
        
        haz=Ci./Jm;
        
end



end


